=====
rtopy
=====


.. image:: https://img.shields.io/pypi/v/rtopy.svg
        :target: https://pypi.python.org/pypi/rtopy

.. image:: https://www.codefactor.io/repository/github/techtonique/rtopy/badge/main
   :target: https://www.codefactor.io/repository/github/techtonique/rtopy/overview/main
   :alt: CodeFactor

.. image:: https://hits.dwyl.com/Techtonique/rtopy.svg?style=flat-square
   :target: http://hits.dwyl.com/Techtonique/rtopy
   :alt: Hits

.. image:: https://img.shields.io/badge/documentation-is_here-green
        :target: https://techtonique.github.io/rtopy/
        :alt: Documentation Status


Call R functions from Python


Install
--------

``pip install rtopy``

Examples
--------

* See .. _this notebook: https://github.com/Techtonique/rtopy/blob/main/rtopy/demo/thierrymoudiki_20240304_rtopyintro.ipynb


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
